==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/d1/dce/water__map_8h.js <==
var water__map_8h =
[
    [ "EnumPropsT< WaterClass >", "d4/d6b/structEnumPropsT_3_01WaterClass_01_4.html", null ],
    [ "DepotPart", "d1/dce/water__map_8h.html#a4775c3a24210b3cc79a5472d25ed45dc", [
      [ "DEPOT_PART_NORTH", "d1/dce/water__map_8h.html#a4775c3a24210b3cc79a5472d25ed45dca93e063ab8534665d6e027def4a9d6aa7", null ],
      [ "DEPOT_PART_SOUTH", "d1/dce/water__map_8h.html#a4775c3a24210b3cc79a5472d25ed45dcaa9e3de3b4214f0ee5c867b0cd3518030", null ],
      [ "DEPOT_PART_END", "d1/dce/water__map_8h.html#a4775c3a24210b3cc79a5472d25ed45dcac462edef2a5d4c21f1c1cf0a74df7b55", null ]
    ] ],
    [ "LockPart", "d1/dce/water__map_8h.html#ae6d4470ca90167985ecfa0e9c6965e74", [
      [ "LOCK_PART_MIDDLE", "d1/dce/water__map_8h.html#ae6d4470ca90167985ecfa0e9c6965e74a752cb4cee685077f67626b3af9c6a821", null ],
      [ "LOCK_PART_LOWER", "d1/dce/water__map_8h.html#ae6d4470ca90167985ecfa0e9c6965e74ae811cc3e744b04ba2635f22d2639cded", null ],
      [ "LOCK_PART_UPPER", "d1/dce/water__map_8h.html#ae6d4470ca90167985ecfa0e9c6965e74a3207dc85b9befc0432c062fb55410f32", null ]
    ] ],
    [ "WaterClass", "d1/dce/water__map_8h.html#a6c3a6d67cca9acdfe331abd6b767391a", [
      [ "WATER_CLASS_SEA", "d1/dce/water__map_8h.html#a6c3a6d67cca9acdfe331abd6b767391aa03f5f63e0f266ace6f5f837a48d363d7", null ],
      [ "WATER_CLASS_CANAL", "d1/dce/water__map_8h.html#a6c3a6d67cca9acdfe331abd6b767391aaa8fe77f6f5abe671f10bd71cdcf2d706", null ],
      [ "WATER_CLASS_RIVER", "d1/dce/water__map_8h.html#a6c3a6d67cca9acdfe331abd6b767391aafc75311275bb9ddaa7be69deddbab68d", null ],
      [ "WATER_CLASS_INVALID", "d1/dce/water__map_8h.html#a6c3a6d67cca9acdfe331abd6b767391aaf18bb5720e6c186540fe167e9256d62d", null ]
    ] ],
    [ "WaterTileType", "d1/dce/water__map_8h.html#a988347bcad4ebc318ffecfff5c6d9026", [
      [ "WATER_TILE_CLEAR", "d1/dce/water__map_8h.html#a988347bcad4ebc318ffecfff5c6d9026af51093f709516fa32d994215763f6c99", null ],
      [ "WATER_TILE_COAST", "d1/dce/water__map_8h.html#a988347bcad4ebc318ffecfff5c6d9026a64b67d788d0eeb83e9a00deaf5123260", null ],
      [ "WATER_TILE_LOCK", "d1/dce/water__map_8h.html#a988347bcad4ebc318ffecfff5c6d9026a93ed50ef989635b50056f95aa0a72bd4", null ],
      [ "WATER_TILE_DEPOT", "d1/dce/water__map_8h.html#a988347bcad4ebc318ffecfff5c6d9026aadb9c04a619db3acffe702b6385cd65e", null ]
    ] ],
    [ "WaterTileTypeBitLayout", "d1/dce/water__map_8h.html#a0ea904cd333b5274c9eb9a2c590a107d", [
      [ "WBL_TYPE_BEGIN", "d1/dce/water__map_8h.html#a0ea904cd333b5274c9eb9a2c590a107daa51f321229560dd16e685ac0eab25d50", null ],
      [ "WBL_TYPE_COUNT", "d1/dce/water__map_8h.html#a0ea904cd333b5274c9eb9a2c590a107daec5b1d4d50d6b3b46c24bee5fd5e0acb", null ],
      [ "WBL_TYPE_NORMAL", "d1/dce/water__map_8h.html#a0ea904cd333b5274c9eb9a2c590a107dae1ae60be9d3a960c81eaa68a96119141", null ],
      [ "WBL_TYPE_LOCK", "d1/dce/water__map_8h.html#a0ea904cd333b5274c9eb9a2c590a107da4f157c652f6d198cc9d30edb2f985927", null ],
      [ "WBL_TYPE_DEPOT", "d1/dce/water__map_8h.html#a0ea904cd333b5274c9eb9a2c590a107da082ee51596aea78c8bbf0a4b8606da91", null ],
      [ "WBL_COAST_FLAG", "d1/dce/water__map_8h.html#a0ea904cd333b5274c9eb9a2c590a107dadf667d4c71f712d40424ec46c3cf4691", null ],
      [ "WBL_LOCK_ORIENT_BEGIN", "d1/dce/water__map_8h.html#a0ea904cd333b5274c9eb9a2c590a107dac822d2f8e875e4fdbe7dff89096c44ce", null ],
      [ "WBL_LOCK_ORIENT_COUNT", "d1/dce/water__map_8h.html#a0ea904cd333b5274c9eb9a2c590a107daa65c646af6915a6e136dc19b2ecb637d", null ],
      [ "WBL_LOCK_PART_BEGIN", "d1/dce/water__map_8h.html#a0ea904cd333b5274c9eb9a2c590a107daefe3f05300de6f3da14373ae1138efb9", null ],
      [ "WBL_LOCK_PART_COUNT", "d1/dce/water__map_8h.html#a0ea904cd333b5274c9eb9a2c590a107dafe2cb9e43bf1c08844bc1b4d97f248bd", null ],
      [ "WBL_DEPOT_PART", "d1/dce/water__map_8h.html#a0ea904cd333b5274c9eb9a2c590a107dac6469c9a5de5d4f267fc15deebc883e7", null ],
      [ "WBL_DEPOT_AXIS", "d1/dce/water__map_8h.html#a0ea904cd333b5274c9eb9a2c590a107dac6fa49a999964f327e94e54f06f43e15", null ]
    ] ],
    [ "GetLockDirection", "d1/dce/water__map_8h.html#a5e53e5e3da8bf70233e43ad5778f5f76", null ],
    [ "GetLockPart", "d1/dce/water__map_8h.html#a3b89265e4b2e20311348b509dd1f7d0f", null ],
    [ "GetOtherShipDepotTile", "d1/dce/water__map_8h.html#a98279099ee32b5d6e1c73e2c6df31e50", null ],
    [ "GetShipDepotAxis", "d1/dce/water__map_8h.html#a448e72bfeb4c62e0ab4c631ffc387667", null ],
    [ "GetShipDepotDirection", "d1/dce/water__map_8h.html#a9257d0e4639cf166c6c145474de83067", null ],
    [ "GetShipDepotNorthTile", "d1/dce/water__map_8h.html#a41a6afb9bf0574aa526fa5bbc764ac62", null ],
    [ "GetShipDepotPart", "d1/dce/water__map_8h.html#a862778c2a6753f2bb2273fd3c0a95939", null ],
    [ "GetWaterClass", "d1/dce/water__map_8h.html#a5bbe6f1d3270b9f78dd4286c937a07b7", null ],
    [ "GetWaterTileRandomBits", "d1/dce/water__map_8h.html#ab1d9c7bab8551c848677cbb1f7c859e8", null ],
    [ "GetWaterTileType", "d1/dce/water__map_8h.html#a4f90bbfa11da29335a2bc007a43c2f4f", null ],
    [ "HasTileWaterClass", "d1/dce/water__map_8h.html#ac1ba60f79d9d4c26feb42fce834616d2", null ],
    [ "HasTileWaterGround", "d1/dce/water__map_8h.html#a647c6889354e078c3f1ab8fea9ae42ac", null ],
    [ "IsCanal", "d1/dce/water__map_8h.html#a017717e722fa547c3bc4fa46cdc141a5", null ],
    [ "IsCoast", "d1/dce/water__map_8h.html#aebe77b3e855de1a20a53bac1748eb7cf", null ],
    [ "IsCoastTile", "d1/dce/water__map_8h.html#a50442a450f2c47ae21629b2e42894fbf", null ],
    [ "IsLock", "d1/dce/water__map_8h.html#a327aca504bed63b4d7dc2cd96fc8c872", null ],
    [ "IsRiver", "d1/dce/water__map_8h.html#af2fc07d4250f6a9bc9f9daee8413347e", null ],
    [ "IsSea", "d1/dce/water__map_8h.html#a0ed6f0452c3b3dd8a92f8bcc14ea4d27", null ],
    [ "IsShipDepot", "d1/dce/water__map_8h.html#a71a7bb87b466dce0b7ebb0ef16460ce8", null ],
    [ "IsShipDepotTile", "d1/dce/water__map_8h.html#a0c49a83975d130084bca6553fbaf5cf4", null ],
    [ "IsTileOnWater", "d1/dce/water__map_8h.html#af9142433fd48c92063f3976210d9a78c", null ],
    [ "IsWater", "d1/dce/water__map_8h.html#a92ff44610ee3ed68f0c844d9a46cfd0c", null ],
    [ "IsWaterTile", "d1/dce/water__map_8h.html#a9738962013d01af4bda7e186da8d1457", null ],
    [ "MakeCanal", "d1/dce/water__map_8h.html#a8096d7534e7e64ca464f60e2ff6bfb74", null ],
    [ "MakeLock", "d1/dce/water__map_8h.html#aea035152aa74de1423a15e54d48ade2f", null ],
    [ "MakeLockTile", "d1/dce/water__map_8h.html#a687ad93be49c4eb00c5d59706b5a63a2", null ],
    [ "MakeRiver", "d1/dce/water__map_8h.html#a3f1fa9aebd3cb0ae3a900544d6571683", null ],
    [ "MakeSea", "d1/dce/water__map_8h.html#aa1a7e993f7518d4d51861b120bcdf8ec", null ],
    [ "MakeShipDepot", "d1/dce/water__map_8h.html#a7d0c9519b24c39f96aac40cd88b9e625", null ],
    [ "MakeShore", "d1/dce/water__map_8h.html#a4fba9bbf05d80abcf332c66eaac55838", null ],
    [ "MakeWater", "d1/dce/water__map_8h.html#a8ca3a957bd8b3c0c0dc9adad14214a89", null ],
    [ "SetWaterClass", "d1/dce/water__map_8h.html#a9efb96bda4940a302372711d1868296d", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/d1/dce/water__map_8h.js <==
var water__map_8h =
[
    [ "EnumPropsT< WaterClass >", "d4/d6b/structEnumPropsT_3_01WaterClass_01_4.html", null ],
    [ "DepotPart", "d1/dce/water__map_8h.html#a4775c3a24210b3cc79a5472d25ed45dc", [
      [ "DEPOT_PART_NORTH", "d1/dce/water__map_8h.html#a4775c3a24210b3cc79a5472d25ed45dca93e063ab8534665d6e027def4a9d6aa7", null ],
      [ "DEPOT_PART_SOUTH", "d1/dce/water__map_8h.html#a4775c3a24210b3cc79a5472d25ed45dcaa9e3de3b4214f0ee5c867b0cd3518030", null ],
      [ "DEPOT_PART_END", "d1/dce/water__map_8h.html#a4775c3a24210b3cc79a5472d25ed45dcac462edef2a5d4c21f1c1cf0a74df7b55", null ]
    ] ],
    [ "LockPart", "d1/dce/water__map_8h.html#ae6d4470ca90167985ecfa0e9c6965e74", [
      [ "LOCK_PART_MIDDLE", "d1/dce/water__map_8h.html#ae6d4470ca90167985ecfa0e9c6965e74a752cb4cee685077f67626b3af9c6a821", null ],
      [ "LOCK_PART_LOWER", "d1/dce/water__map_8h.html#ae6d4470ca90167985ecfa0e9c6965e74ae811cc3e744b04ba2635f22d2639cded", null ],
      [ "LOCK_PART_UPPER", "d1/dce/water__map_8h.html#ae6d4470ca90167985ecfa0e9c6965e74a3207dc85b9befc0432c062fb55410f32", null ]
    ] ],
    [ "WaterClass", "d1/dce/water__map_8h.html#a6c3a6d67cca9acdfe331abd6b767391a", [
      [ "WATER_CLASS_SEA", "d1/dce/water__map_8h.html#a6c3a6d67cca9acdfe331abd6b767391aa03f5f63e0f266ace6f5f837a48d363d7", null ],
      [ "WATER_CLASS_CANAL", "d1/dce/water__map_8h.html#a6c3a6d67cca9acdfe331abd6b767391aaa8fe77f6f5abe671f10bd71cdcf2d706", null ],
      [ "WATER_CLASS_RIVER", "d1/dce/water__map_8h.html#a6c3a6d67cca9acdfe331abd6b767391aafc75311275bb9ddaa7be69deddbab68d", null ],
      [ "WATER_CLASS_INVALID", "d1/dce/water__map_8h.html#a6c3a6d67cca9acdfe331abd6b767391aaf18bb5720e6c186540fe167e9256d62d", null ]
    ] ],
    [ "WaterTileType", "d1/dce/water__map_8h.html#a988347bcad4ebc318ffecfff5c6d9026", [
      [ "WATER_TILE_CLEAR", "d1/dce/water__map_8h.html#a988347bcad4ebc318ffecfff5c6d9026af51093f709516fa32d994215763f6c99", null ],
      [ "WATER_TILE_COAST", "d1/dce/water__map_8h.html#a988347bcad4ebc318ffecfff5c6d9026a64b67d788d0eeb83e9a00deaf5123260", null ],
      [ "WATER_TILE_LOCK", "d1/dce/water__map_8h.html#a988347bcad4ebc318ffecfff5c6d9026a93ed50ef989635b50056f95aa0a72bd4", null ],
      [ "WATER_TILE_DEPOT", "d1/dce/water__map_8h.html#a988347bcad4ebc318ffecfff5c6d9026aadb9c04a619db3acffe702b6385cd65e", null ]
    ] ],
    [ "WaterTileTypeBitLayout", "d1/dce/water__map_8h.html#a0ea904cd333b5274c9eb9a2c590a107d", [
      [ "WBL_TYPE_BEGIN", "d1/dce/water__map_8h.html#a0ea904cd333b5274c9eb9a2c590a107daa51f321229560dd16e685ac0eab25d50", null ],
      [ "WBL_TYPE_COUNT", "d1/dce/water__map_8h.html#a0ea904cd333b5274c9eb9a2c590a107daec5b1d4d50d6b3b46c24bee5fd5e0acb", null ],
      [ "WBL_TYPE_NORMAL", "d1/dce/water__map_8h.html#a0ea904cd333b5274c9eb9a2c590a107dae1ae60be9d3a960c81eaa68a96119141", null ],
      [ "WBL_TYPE_LOCK", "d1/dce/water__map_8h.html#a0ea904cd333b5274c9eb9a2c590a107da4f157c652f6d198cc9d30edb2f985927", null ],
      [ "WBL_TYPE_DEPOT", "d1/dce/water__map_8h.html#a0ea904cd333b5274c9eb9a2c590a107da082ee51596aea78c8bbf0a4b8606da91", null ],
      [ "WBL_COAST_FLAG", "d1/dce/water__map_8h.html#a0ea904cd333b5274c9eb9a2c590a107dadf667d4c71f712d40424ec46c3cf4691", null ],
      [ "WBL_LOCK_ORIENT_BEGIN", "d1/dce/water__map_8h.html#a0ea904cd333b5274c9eb9a2c590a107dac822d2f8e875e4fdbe7dff89096c44ce", null ],
      [ "WBL_LOCK_ORIENT_COUNT", "d1/dce/water__map_8h.html#a0ea904cd333b5274c9eb9a2c590a107daa65c646af6915a6e136dc19b2ecb637d", null ],
      [ "WBL_LOCK_PART_BEGIN", "d1/dce/water__map_8h.html#a0ea904cd333b5274c9eb9a2c590a107daefe3f05300de6f3da14373ae1138efb9", null ],
      [ "WBL_LOCK_PART_COUNT", "d1/dce/water__map_8h.html#a0ea904cd333b5274c9eb9a2c590a107dafe2cb9e43bf1c08844bc1b4d97f248bd", null ],
      [ "WBL_DEPOT_PART", "d1/dce/water__map_8h.html#a0ea904cd333b5274c9eb9a2c590a107dac6469c9a5de5d4f267fc15deebc883e7", null ],
      [ "WBL_DEPOT_AXIS", "d1/dce/water__map_8h.html#a0ea904cd333b5274c9eb9a2c590a107dac6fa49a999964f327e94e54f06f43e15", null ]
    ] ],
    [ "GetLockDirection", "d1/dce/water__map_8h.html#a5e53e5e3da8bf70233e43ad5778f5f76", null ],
    [ "GetLockPart", "d1/dce/water__map_8h.html#a3b89265e4b2e20311348b509dd1f7d0f", null ],
    [ "GetOtherShipDepotTile", "d1/dce/water__map_8h.html#a98279099ee32b5d6e1c73e2c6df31e50", null ],
    [ "GetShipDepotAxis", "d1/dce/water__map_8h.html#a448e72bfeb4c62e0ab4c631ffc387667", null ],
    [ "GetShipDepotDirection", "d1/dce/water__map_8h.html#a9257d0e4639cf166c6c145474de83067", null ],
    [ "GetShipDepotNorthTile", "d1/dce/water__map_8h.html#a41a6afb9bf0574aa526fa5bbc764ac62", null ],
    [ "GetShipDepotPart", "d1/dce/water__map_8h.html#a862778c2a6753f2bb2273fd3c0a95939", null ],
    [ "GetWaterClass", "d1/dce/water__map_8h.html#a5bbe6f1d3270b9f78dd4286c937a07b7", null ],
    [ "GetWaterTileRandomBits", "d1/dce/water__map_8h.html#ab1d9c7bab8551c848677cbb1f7c859e8", null ],
    [ "GetWaterTileType", "d1/dce/water__map_8h.html#a4f90bbfa11da29335a2bc007a43c2f4f", null ],
    [ "HasTileWaterClass", "d1/dce/water__map_8h.html#ac1ba60f79d9d4c26feb42fce834616d2", null ],
    [ "HasTileWaterGround", "d1/dce/water__map_8h.html#a647c6889354e078c3f1ab8fea9ae42ac", null ],
    [ "IsCanal", "d1/dce/water__map_8h.html#a017717e722fa547c3bc4fa46cdc141a5", null ],
    [ "IsCoast", "d1/dce/water__map_8h.html#aebe77b3e855de1a20a53bac1748eb7cf", null ],
    [ "IsCoastTile", "d1/dce/water__map_8h.html#a50442a450f2c47ae21629b2e42894fbf", null ],
    [ "IsDockingTile", "d1/dce/water__map_8h.html#a010b151ec9c890186263a5cebc0d42d5", null ],
    [ "IsLock", "d1/dce/water__map_8h.html#a327aca504bed63b4d7dc2cd96fc8c872", null ],
    [ "IsPossibleDockingTile", "d1/dce/water__map_8h.html#a677af400a68ad5a1bdaf851de71d3bee", null ],
    [ "IsRiver", "d1/dce/water__map_8h.html#af2fc07d4250f6a9bc9f9daee8413347e", null ],
    [ "IsSea", "d1/dce/water__map_8h.html#a0ed6f0452c3b3dd8a92f8bcc14ea4d27", null ],
    [ "IsShipDepot", "d1/dce/water__map_8h.html#a71a7bb87b466dce0b7ebb0ef16460ce8", null ],
    [ "IsShipDepotTile", "d1/dce/water__map_8h.html#a0c49a83975d130084bca6553fbaf5cf4", null ],
    [ "IsTileOnWater", "d1/dce/water__map_8h.html#af9142433fd48c92063f3976210d9a78c", null ],
    [ "IsWater", "d1/dce/water__map_8h.html#a92ff44610ee3ed68f0c844d9a46cfd0c", null ],
    [ "IsWaterTile", "d1/dce/water__map_8h.html#a9738962013d01af4bda7e186da8d1457", null ],
    [ "MakeCanal", "d1/dce/water__map_8h.html#a8096d7534e7e64ca464f60e2ff6bfb74", null ],
    [ "MakeLock", "d1/dce/water__map_8h.html#aea035152aa74de1423a15e54d48ade2f", null ],
    [ "MakeLockTile", "d1/dce/water__map_8h.html#a687ad93be49c4eb00c5d59706b5a63a2", null ],
    [ "MakeRiver", "d1/dce/water__map_8h.html#a3f1fa9aebd3cb0ae3a900544d6571683", null ],
    [ "MakeSea", "d1/dce/water__map_8h.html#aa1a7e993f7518d4d51861b120bcdf8ec", null ],
    [ "MakeShipDepot", "d1/dce/water__map_8h.html#a7d0c9519b24c39f96aac40cd88b9e625", null ],
    [ "MakeShore", "d1/dce/water__map_8h.html#a4fba9bbf05d80abcf332c66eaac55838", null ],
    [ "MakeWater", "d1/dce/water__map_8h.html#a8ca3a957bd8b3c0c0dc9adad14214a89", null ],
    [ "SetDockingTile", "d1/dce/water__map_8h.html#a6ec9386b7faf2d730525b3cf13ed0f9b", null ],
    [ "SetWaterClass", "d1/dce/water__map_8h.html#a9efb96bda4940a302372711d1868296d", null ]
];
